@@ -112,16 +112,17 @@ class Respuesta(BaseModel):
         use_enum_values = True
 
     def build_xml(self):
-        mensaje = etree.Element('mensaje', categoria=self.categoria)
-        orden_pago = etree.SubElement(mensaje, 'respuesta')
+        qname = etree.QName('http://www.w3.org/2001/XMLSchema-instance', 'type')
+        respuesta = etree.Element('respuesta', xlmns='http://www.praxis.com.mx/')
+        mensaje = etree.SubElement(respuesta, 'mensaje', {qname: 'mensaje'}, categoria=self.categoria)  # noqa: E501
 
         for element, value in self.dict(exclude={'categoria'}).items():  # noqa: WPS110
             if element in self.__fields__:
                 upper_camel_case_element = to_upper_camel_case(element)
-                subelement = etree.SubElement(orden_pago, upper_camel_case_element)
+                subelement = etree.SubElement(mensaje, upper_camel_case_element)
                 subelement.text = str(value)
 
-        return mensaje
+        return respuesta
 
     @classmethod
     def parse_xml(cls, respuesta_xml):
